@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*  GMime
- *  Copyright (C) 2000-2007 Jeffrey Stedfast
+ *  Copyright (C) 2000-2008 Jeffrey Stedfast
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public License
@@ -30,14 +30,6 @@ int g_mime_strcase_equal (gconstpointer v, gconstpointer v2);
 
 guint g_mime_strcase_hash (gconstpointer key);
 
-#ifndef HAVE_STRNCASECMP
-int strncasecmp (const char *s1, const char *s2, size_t n);
-#endif
-
-#ifndef HAVE_STRCASECMP
-int strcasecmp (const char *s1, const char *s2);
-#endif
-
 G_END_DECLS
 
 #endif /* __GMIME_COMMON_H__ */
